==> calligraplan_3.1.0.orig.tar.xz: calligraplan-3.1.0/src/libs/ui/kptmainprojectdialog.h <==
/* This file is part of the KDE project
   Copyright (C) 2003 - 2007 Dag Andersen <danders@get2net.dk>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPTMAINPROJECTDIALOG_H
#define KPTMAINPROJECTDIALOG_H

#include "kplatoui_export.h"

#include <KoDialog.h>


namespace KPlato
{

class Project;
class MainProjectPanel;
class MacroCommand;


class KPLATOUI_EXPORT MainProjectDialog : public KoDialog {
    Q_OBJECT
public:
    explicit MainProjectDialog(Project &project, QWidget *parent=0, bool edit=true);

    MacroCommand *buildCommand();

    bool loadSharedResources();

Q_SIGNALS:
    void dialogFinished(int);
    void sigLoadSharedResources(const QString &file, const QUrl &projects, bool loadProjects=false);
    void loadResourceAssignments(QUrl url);
    void clearResourceAssignments();

protected Q_SLOTS:
    void slotRejected();
    void slotOk();

private:
    Project &project;
    MainProjectPanel *panel;
};

}  //KPlato namespace

#endif // MAINPROJECTDIALOG_H

==> calligraplan_3.3.0.orig.tar.xz: calligraplan-3.3.0/src/libs/ui/kptmainprojectdialog.h <==
/* This file is part of the KDE project
   Copyright (C) 2003 - 2007 Dag Andersen <danders@get2net.dk>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef KPTMAINPROJECTDIALOG_H
#define KPTMAINPROJECTDIALOG_H

#include "planui_export.h"

#include <KoDialog.h>


namespace KPlato
{

class Project;
class MainProjectPanel;
class MacroCommand;


class PLANUI_EXPORT MainProjectDialog : public KoDialog {
    Q_OBJECT
public:
    explicit MainProjectDialog(Project &project, QWidget *parent=0, bool edit=true);

    MacroCommand *buildCommand();

    bool loadSharedResources();

Q_SIGNALS:
    void dialogFinished(int);
    void sigLoadSharedResources(const QString &file, const QUrl &projects, bool loadProjects=false);
    void loadResourceAssignments(QUrl url);
    void clearResourceAssignments();

protected Q_SLOTS:
    void slotRejected();
    void slotOk();

private:
    Project &project;
    MainProjectPanel *panel;
};

}  //KPlato namespace

#endif // MAINPROJECTDIALOG_H
